@@ -1,20 +1,3 @@
-#' @keywords internal
-.restore_factor_levels <- function(predictions, data) {
-  original_factors <- data[sapply(data, is.factor)]
-
-  for (i in names(predictions)) {
-    if (i %in% names(original_factors)) {
-      predictions[[i]] <- factor(predictions[[i]], levels = levels(original_factors[[i]]))
-    }
-  }
-
-  predictions
-}
-
-
-
-
-
 #' Convert to Numeric if Possible
 #'
 #' Tries to convert vector to numeric if possible. Otherwise, leaves it as is.
