@@ -13,22 +13,22 @@ if (require("testthat") && require("modelbased") && require("mgcv") && require("
 
   test_that("estimate_means - mgcv gam", {
     estim <- estimate_means(model)
-    testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 5))
+    expect_equal(c(nrow(estim), ncol(estim)), c(3, 5))
   })
 
   test_that("estimate_contrasts - mgcv gam", {
     estim <- estimate_contrasts(model)
-    testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 10))
+    expect_equal(c(nrow(estim), ncol(estim)), c(3, 10))
   })
 
   test_that("estimate_response - mgcv gam", {
     estim <- estimate_response(model)
-    testthat::expect_equal(c(nrow(estim), ncol(estim)), c(150, 5))
+    expect_equal(c(nrow(estim), ncol(estim)), c(150, 6))
   })
 
   test_that("estimate_link - mgcv gam", {
     estim <- estimate_link(model)
-    testthat::expect_equal(c(nrow(estim), ncol(estim)), c(52, 5))
+    expect_equal(c(nrow(estim), ncol(estim)), c(30, 6))
   })
 
   model <- mgcv::gam(Sepal.Length ~ Petal.Length + s(Sepal.Width) + s(Species, bs = "fs"), data = iris)
@@ -39,14 +39,14 @@ if (require("testthat") && require("modelbased") && require("mgcv") && require("
 
     test_that("estimate_response - mgcv gamm", {
       estim <- estimate_response(model)
-      testthat::expect_equal(c(nrow(estim), ncol(estim)), c(150, 6))
+      expect_equal(c(nrow(estim), ncol(estim)), c(150, 7))
     })
   }
 
   if (!osx) {
     test_that("estimate_link - mgcv gamm", {
       estim <- estimate_link(model, length = 4)
-      testthat::expect_equal(c(nrow(estim), ncol(estim)), c(16, 5))
+      expect_equal(c(nrow(estim), ncol(estim)), c(16, 6))
     })
   }
 
@@ -57,11 +57,11 @@ if (require("testthat") && require("modelbased") && require("mgcv") && require("
   #
   # test_that("estimate_response - gamm4", {
   #   estim <- estimate_response(model)
-  #   testthat::expect_equal(c(nrow(estim), ncol(estim)), c(150, 5))
+  #   expect_equal(c(nrow(estim), ncol(estim)), c(150, 5))
   # })
   #
   # test_that("estimate_link - gamm4", {
   #   estim <- estimate_link(model, length=4)
-  #   testthat::expect_equal(c(nrow(estim), ncol(estim)), c(16, 5))
+  #   expect_equal(c(nrow(estim), ncol(estim)), c(16, 5))
   # })
 }
